@@ -128,7 +128,7 @@ prod.spline <- function(x,
         if(deriv!=0) {
           P.deriv <- list()
           for(i in 1:length(tp)) P.deriv[[i]] <- matrix(0,1,ncol(tp[[i]]))
-          deriv.index <- deriv.index - length(which((K[,1]==0)))
+          deriv.index <- deriv.index - length(which((K[1:deriv.index,1]==0)))
           while(deriv.index<=0) deriv.index <- deriv.index + 1
           P.deriv[[deriv.index]] <- matrix(NA,1,ncol(tp[[deriv.index]]))
           P[,!is.na(as.numeric(glp.model.matrix(P.deriv)))] <- 0
@@ -236,7 +236,7 @@ predict.kernel.spline <- function(x,
     if(is.null(tau))
       fit.spline <- cbind(fit.spline[[1]],se=fit.spline[[2]])
     else
-      fit.spline <- cbind(fit.spline,se=ifelse(NCOL(fit.spline)>1,(fit.spline[,3]-fit.spline[,1])/1.96,NA))
+      fit.spline <- cbind(fit.spline,se=ifelse(NCOL(fit.spline)>1,(fit.spline[,3]-fit.spline[,1])/qnorm(0.975),NA))
 
     if(is.null(tau))
       htt <- hatvalues(model)
@@ -306,7 +306,7 @@ predict.kernel.spline <- function(x,
           if(is.null(tau))
             fit.spline[zz,] <- cbind(tmp[[1]],tmp[[2]])
           else
-            fit.spline[zz,] <- cbind(tmp,(tmp[,3]-tmp[,1])/1.96)
+            fit.spline[zz,] <- cbind(tmp,(tmp[,3]-tmp[,1])/qnorm(0.975))
           rm(tmp)
         }
       } else {
@@ -348,7 +348,7 @@ predict.kernel.spline <- function(x,
           if(is.null(tau))
             fit.spline[zz,] <- cbind(tmp[[1]],tmp[[2]])
           else
-            fit.spline[zz,] <- cbind(tmp,(tmp[,3]-tmp[,1])/1.96)
+            fit.spline[zz,] <- cbind(tmp,(tmp[,3]-tmp[,1])/qnorm(0.975))
 
           rm(tmp)
         }
@@ -389,7 +389,7 @@ predict.kernel.spline <- function(x,
           if(is.null(tau))
             fit.spline[zz,] <- cbind(tmp[[1]],tmp[[2]])
           else
-            fit.spline[zz,] <- cbind(tmp,(tmp[,3]-tmp[,1])/1.96)
+            fit.spline[zz,] <- cbind(tmp,(tmp[,3]-tmp[,1])/qnorm(0.975))
 
           rm(tmp)
         }
@@ -424,7 +424,7 @@ predict.kernel.spline <- function(x,
           if(is.null(tau))
             fit.spline[zz,] <- cbind(tmp[[1]],tmp[[2]])
           else
-            fit.spline[zz,] <- cbind(tmp,(tmp[,3]-tmp[,1])/1.96)
+            fit.spline[zz,] <- cbind(tmp,(tmp[,3]-tmp[,1])/qnorm(0.975))
 
           rm(tmp)
         }
@@ -968,7 +968,7 @@ predict.factor.spline <- function(x,
   if(is.null(tau))
     fit.spline <- cbind(fit.spline[[1]],se=fit.spline[[2]])
   else
-    fit.spline <- cbind(fit.spline,se=ifelse(NCOL(fit.spline)>1,(fit.spline[,3]-fit.spline[,1])/1.96,NA))
+    fit.spline <- cbind(fit.spline,se=ifelse(NCOL(fit.spline)>1,(fit.spline[,3]-fit.spline[,1])/qnorm(0.975),NA))
 
   console <- printClear(console)
   console <- printPop(console)
@@ -1380,8 +1380,8 @@ cv.kernel.spline <- function(x,
 
     } else {
       ## No predictors for which degree > 0
-      z.factor <- data.frame(factor(z[,1]))
-      if(num.z > 1) for(i in 2:num.z) z.factor <- data.frame(z.factor,factor(z[,i]))
+      z.factor <- data.frame(factor(z[,1]),ordered=is.ordered.z[1])
+      if(num.z > 1) for(i in 2:num.z) z.factor <- data.frame(z.factor,factor(z[,i],ordered=is.ordered.z[i]))
       for(i in 1:nrow.z.unique) {
         zz <- ind == ind.vals[i]
         L <- prod.kernel(Z=z,z=z.unique[ind.vals[i],],lambda=lambda,is.ordered.z=is.ordered.z)
