@@ -1,16 +1,22 @@
 /*-------------------------------------------------------------------------------------*/
-/*  NOMAD - Nonlinear Optimization by Mesh Adaptive Direct search - version 3.6.2        */
+/*  NOMAD - Nonlinear Optimization by Mesh Adaptive Direct search - version 3.8.0      */
 /*                                                                                     */
-/*  Copyright (C) 2001-2012  Mark Abramson        - the Boeing Company, Seattle        */
-/*                           Charles Audet        - Ecole Polytechnique, Montreal      */
-/*                           Gilles Couture       - Ecole Polytechnique, Montreal      */
-/*                           John Dennis          - Rice University, Houston           */
-/*                           Sebastien Le Digabel - Ecole Polytechnique, Montreal      */
-/*                           Christophe Tribes    - Ecole Polytechnique, Montreal      */
 /*                                                                                     */
-/*  funded in part by AFOSR and Exxon Mobil                                            */
+/*  NOMAD - version 3.8.0 has been created by                                          */
+/*                 Charles Audet        - Ecole Polytechnique de Montreal              */
+/*                 Sebastien Le Digabel - Ecole Polytechnique de Montreal              */
+/*                 Christophe Tribes    - Ecole Polytechnique de Montreal              */
+/*                                                                                     */
+/*  The copyright of NOMAD - version 3.8.0 is owned by                                 */
+/*                 Sebastien Le Digabel - Ecole Polytechnique de Montreal              */
+/*                 Christophe Tribes    - Ecole Polytechnique de Montreal              */
+/*                                                                                     */
+/*  NOMAD v3 has been funded by AFOSR and Exxon Mobil.                                 */
+/*                                                                                     */
+/*  NOMAD v3 is a new version of NOMAD v1 and v2. NOMAD v1 and v2 were created and     */
+/*  developed by Mark Abramson, Charles Audet, Gilles Couture and John E. Dennis Jr.,  */
+/*  and were funded by AFOSR and Exxon Mobil.                                          */
 /*                                                                                     */
-/*  Author: Sebastien Le Digabel                                                       */
 /*                                                                                     */
 /*  Contact information:                                                               */
 /*    Ecole Polytechnique de Montreal - GERAD                                          */
@@ -34,56 +40,58 @@
 /*  You can find information on the NOMAD software at www.gerad.ca/nomad               */
 /*-------------------------------------------------------------------------------------*/
 /**
-  \file   Model_Sorted_Point.cpp
-  \brief  Interpolation point with distance to model center (implementation)
-  \author Sebastien Le Digabel
-  \date   2010-11-15
-  \see    Model_Sorted_Point.hpp
-*/
+ \file   Model_Sorted_Point.cpp
+ \brief  Interpolation point with distance to model center (implementation)
+ \author Sebastien Le Digabel
+ \date   2010-11-15
+ \see    Model_Sorted_Point.hpp
+ */
 #include "Model_Sorted_Point.hpp"
-using namespace std; // zhenghua
 
 /*---------------------------------------------------------*/
 /*                        constructor                      */
 /*---------------------------------------------------------*/
-NOMAD::Model_Sorted_Point::Model_Sorted_Point
-( NOMAD::Point * x , const NOMAD::Point & center ) : _x(x)
+NOMAD::Model_Sorted_Point::Model_Sorted_Point ( NOMAD::Point * x ,
+                                               const NOMAD::Point & center ) : _x(x)
 {
-  int i , n = center.size();
-  if ( x && x->size() == n ) {
-    _dist = 0.0;
-    for ( i = 0 ; i < n ; ++i )
-      if ( (*x)[i].is_defined() && center[i].is_defined() ) {
-	_dist += ( (*x)[i] - center[i] ).pow2();
-      }
-      else {
-	_dist.clear();
-	break;
-      }
-  }
+    int i , n = center.size();
+    if ( x && x->size() == n )
+    {
+        _dist = 0.0;
+        for ( i = 0 ; i < n ; ++i )
+            if ( (*x)[i].is_defined() && center[i].is_defined() )
+            {
+                _dist += ( (*x)[i] - center[i] ).pow2();
+            }
+            else
+            {
+                
+                _dist.clear();
+                break;
+            }
+    }
 }
 
 /*---------------------------------------------------------*/
 /*                   affectation operator                  */
 /*---------------------------------------------------------*/
-NOMAD::Model_Sorted_Point & NOMAD::Model_Sorted_Point::operator =
-( const NOMAD::Model_Sorted_Point & x )
+NOMAD::Model_Sorted_Point & NOMAD::Model_Sorted_Point::operator = ( const NOMAD::Model_Sorted_Point & x )
 {
-  _x    = x._x;
-  _dist = x._dist;
-  return *this;
+    _x    = x._x;
+    _dist = x._dist;
+    return *this;
 }
 
 /*---------------------------------------------------------*/
 /*                    comparison operator                  */
 /*---------------------------------------------------------*/
-bool NOMAD::Model_Sorted_Point::operator <
-( const Model_Sorted_Point & x ) const
+bool NOMAD::Model_Sorted_Point::operator < ( const Model_Sorted_Point & x ) const
 {
-  if ( _dist.is_defined() ) {
-    if ( !x._dist.is_defined() )
-      return true;
-    return _dist < x._dist;
-  }
-  return false;
+    if ( _dist.is_defined() )
+    {
+        if ( !x._dist.is_defined() )
+            return true;
+        return _dist < x._dist;
+    }
+    return false;
 }
